__title__ = "esa"
__package_name__ = "esa"
__description__ = "Easy SimAuto (ESA): An easy-to-use Python connector to PowerWorld Simulator " \
                  "Automation Server (SimAuto)"
__author__ = "Zeyu Mao"
__github__ = "https://github.com/mzy2240/ESA"
__docs__ = "https://mzy2240.github.io/ESA"
__tracker__ = "https://github.com/mzy2240/ESA/issues"
__pypi__ = "https://pypi.org/project/esa/"
__email__ = "me@zeyumao.com"
__license__ = "Apache License 2.0"
__copyright__ = "Copyright 2022 - Zeyu Mao"
__version__ = "1.3.3"
